import { DetailPreviewType } from '../middleware/detailPreview';
import { OptionGroupRenderAsType } from '../middleware/types';
export declare type DataRow = {
    icon?: string;
    category?: string;
    label?: string;
    description?: string;
    __actionIcon?: string;
    __image?: string;
    __heading?: string;
    /** @deprecated Use \_\_heading */
    __breadcrumbs?: string;
    __extraHTML?: string | ((elem: HTMLElement, record: any) => void);
    __preserveSVG?: boolean;
    [key: string]: any;
} | string;
export declare type SearchFunction = (input: string) => DataRow[] | Promise<DataRow[]>;
export declare type MultiSearchFunction = (input: string) => {
    [key: string]: DataRow[];
} | Promise<{
    [key: string]: DataRow[];
}>;
/** Options to customize CommandBar properties for `key`. */
export interface AddContextOptions {
    /** quickFind allows the `key` to be searchable from the top-level of the Bar, alongside commands. */
    quickFindOptions?: {
        /**
         * Turn on autoExecute for `key`. If only one command is available for an option from this `key`, that command will
         * automatically be executed when a user selects the option.
         */
        autoExecute?: boolean;
        /** The category header name for `key` objects shown during search (not used if `unfurl` is on). */
        categoryName?: string;
        /** Turn on quickFind for `key`. */
        quickFind?: boolean;
        /** Turn on unfurling for `key`. */
        unfurl?: boolean;
        /** Show records by default with no input */
        showInDefaultEmptyState?: boolean;
        /** Option list limit: During quickFind, set a limit on the amount of options that can be shown in the category */
        maxOptionsCount?: number;
        /** Sort key */
        categorySortKey?: number;
    };
    /** Options to customize the style of `key` objects. */
    renderOptions?: {
        /**
         * Default icon to show alongside `key` objects. Can be a URL (absolute or relative) or emoji character. You can
         * specify a custom icon for every object by setting an `.icon` field.
         */
        defaultIcon?: string;
        detail?: DetailPreviewType;
        /** The value key of `key` objects you want to use to display the object's description (subtext under label). */
        descriptionKey?: string;
        /** The value key of `key` objects you want to use to display the object's label. */
        labelKey?: string;
        renderAs?: OptionGroupRenderAsType;
        searchTabEnabled?: boolean;
    };
    /** Options to customize the search behavior for `key`. */
    searchOptions?: {
        /**
         * A list of object fields to be searched. If a custom `searchFunction` is provided, matches will be highlighted in
         * these fields. Field names will be transformed from _camelCase_ or _snake_case_ into _Sentence case_.
         */
        fields?: (string | {
            key: string;
            label: string;
        })[];
        /**
         * Adds a custom search function to CommandBar for `key`. This custom search function should take a single argument `input` and return an array of results.
         *
         * The function will be called whenever a user types in a scenario where they might be searching for `context.key`:
         *
         * * A command has been selected and the user is prompted for an argument referencing `context.key`
         * * Quickfind is turned on for `context.key`.
         *
         * Results from the custom search function should be filtered; they will not be filtered by CommandBar. This means
         * that the search results will be identical to those returned by the function.
         *
         * @param input What the user has typed into CommandBar
         */
        searchFunction?: SearchFunction;
        sortFunction?: (a: DataRow, b: DataRow) => number;
    };
}
export interface ArgumentOptions {
    /** The value key of `key` objects you want to use to display the object's label. */
    labelKey?: string;
    /** The value key of `key` objects you want to use to display the object's description (subtext under label). */
    descriptionKey?: string;
    /**
     * Default icon to show alongside `key` objects. Can be a URL (absolute or relative) or emoji character. You can
     * specify a custom icon for every object by setting an `.icon` field.
     */
    defaultIcon?: string;
    detail?: DetailPreviewType;
    renderAs?: OptionGroupRenderAsType;
    searchTabEnabled?: boolean;
    /**
     * A list of object fields to be searched. If a custom `searchFunction` is provided, matches will be highlighted in
     * these fields. Field names will be transformed from _camelCase_ or _snake_case_ into _Sentence case_.
     */
    searchableFields?: (string | {
        key: string;
        label: string;
    })[];
    onInputChange?: SearchFunction;
}
export interface RecordOptions extends ArgumentOptions {
    recordOptions?: {
        /** The category header name for `key` objects shown during search (not used if `unfurl` is on). */
        categoryName?: string;
        /** Turn on unfurling for `key`. */
        unfurl?: boolean;
        /** Show records by default with no input */
        showInDefaultEmptyState?: boolean;
        /** Option list limit: During quickFind, set a limit on the amount of options that can be shown in the category */
        maxOptionsCount?: number;
        /** Sort key */
        categorySortKey?: number;
    };
}
