interface EventCommandDetailsBase {
    icon: string | null;
}
interface EventLinkCommandDetails {
    url: string;
}
export declare type EventCommandDetails = EventCommandDetailsBase | EventLinkCommandDetails;
export interface AbandonedSearchEvent {
    type: 'abandoned_search';
    /** Event data passed for `abandoned_search` events (deadends). */
    /** The id of the currently active command, if there is one. */
    command?: number;
    /** DEPRECATED. The text of the deadend. */
    ['inputText[*]']: string;
    /** The text of the deadend. */
    inputText: string;
    /** The context key of the currently active resource, if there is one. */
    resource?: string;
    /** The trigger for the deadend. */
    trigger: 'Backspaced' | 'Closed with text' | 'Resetting search';
    /** The number of {CommandOptions, ParameterOptions}, if there are any. */
    results?: {
        numCommands: number;
        numRecords: number;
    };
    /** command_ids of previously executed commands in the session */
    previousCommands?: string[];
}
export interface ClosedEvent {
    type: 'closed';
    /** Event data passed for `command_execution` events. */
    /** The user's input text when the bar was closed. */
    inputText: string;
    /** True if this command was triggered by a shortcut. */
    shortcut?: boolean;
}
export declare type ReportingPreviewEngagementType = 'scrolled' | 'clicked_link' | 'watched_video';
export declare type ChecklistEngagementType = 'expanded' | 'collapsed' | 'dismissed';
export declare type ChecklistItemEngagementType = 'expanded' | 'completed' | 'cta_clicked' | 'skipped';
export declare type EngagementType = ChecklistEngagementType | ChecklistItemEngagementType;
export declare type PushTrigger = {
    type: 'when_conditions_pass';
} | {
    type: 'on_command_execution';
    meta: {
        command: string;
    };
} | {
    type: 'on_event';
    meta: {
        event: string;
    };
};
export interface ChecklistEvent {
    type: 'questlist_shown' | 'questlist_engagement';
    id: number;
    trigger: PushTrigger;
    title: string;
    total_items: number;
    completed_items: number;
}
export interface ChecklistItemEvent {
    type: 'questlist_item_engagement';
    id: number;
    checklist_id: number;
    title: string;
    cta?: string;
    goal: {
        type: 'page_visited';
        value: string;
    } | {
        type: 'command_executed';
        meta: {
            command: string;
        };
    } | {
        type: 'element_clicked';
        value: string;
    } | {
        type: 'conditions_met';
    } | {
        type: 'cta_clicked';
    } | {
        type: 'event_tracked';
        event: string;
    };
    completed: boolean;
}
export interface PreviewEvent {
    type: 'preview_shown' | 'next_step_selected' | 'preview_link_opened' | 'preview_engagement';
    preview_type?: 'html' | 'markdown' | 'plaintext' | 'react' | 'video' | 'component';
    form_factor?: 'inline' | 'popover';
    time_shown?: number;
    engagement?: ReportingPreviewEngagementType;
    source?: {
        command?: string;
        record?: string;
    };
    id?: string;
}
export interface NudgeEvent {
    type: 'nudge_seen' | 'nudge_clicked';
    id: string;
    slug: string;
    template_source: string;
    frequency_limit: 'no_limit' | 'once_per_session' | 'once_per_user' | 'until_interaction';
    trigger: PushTrigger;
    step: {
        id: number;
        title: string;
    } | undefined;
}
export declare type ExecutionEventSource = {
    type: 'bar';
} | {
    type: 'nudge';
    id: number | string;
} | {
    type: 'questlist';
    id: number;
};
export interface CommandExecutionEvent {
    type: 'command_execution';
    /** Event data passed for `command_execution` events. */
    /** The category id of the command. Only provided if the command has a category. */
    category?: string | number | null;
    /** The text of the category */
    categoryText?: string;
    /**
     * The unique id of the command. For commands defined via the Editor, the value will be a number. For programmatic
     * commands, the `name` (string) provided will be used.
     */
    command: number | string | undefined;
    /** The text of the command */
    commandText: string;
    /** The source of the command. */
    source: string;
    /** The source of the command execution. */
    eventSource: ExecutionEventSource;
    /** DEPRECATED. The text input.*/
    ['inputText[*]']: string;
    /** The text input.*/
    inputText?: string;
    /** True if this command was triggered by a shortcut. */
    shortcut?: boolean;
    /** Ranking order of the command option */
    ranking?: number;
    /** command_ids of previously executed commands in the session */
    previousCommands?: string[];
    /** Command types, as defined at: https://www.commandbar.com/docs/commands/overview */
    commandType?: 'admin' | 'link' | 'script' | 'clickByXpath' | 'clickBySelector' | 'click' | 'callback' | 'builtin' | 'webhook' | 'request' | 'video' | 'helpdoc' | 'appcues';
    /** Selected arguments */
    selections?: Record<string, unknown>;
    commandDetails: EventCommandDetails;
}
export interface EndUserShortcutChangedEvent {
    type: 'shortcut_edited';
    /** Event data passed for `command_execution` events. */
    /** The category id of the command. Only provided if the command has a category. */
    category?: number | null;
    /**
     * The unique id of the command. For commands defined via the Editor, the value will be a number. For programmatic
     * commands, the `name` (string) provided will be used.
     */
    command: number | string | undefined;
    /** The text of the command */
    commandText: string;
    /** The source of the command. */
    source: string;
    /** The updated shortcut. */
    oldShortcut: string;
    newShortcut: string;
    defaultShortcut: string;
}
export interface CommandSuggestionEvent {
    type: 'command_suggestion';
    /** The text of the suggestion. */
    text: string;
}
export interface OpenedEvent {
    type: 'opened';
    /** Event data passed for `command_execution` events. */
    /**
     * The entrypoint through which the bar was opened.
     *
     * * `launcher`: Click on the provided CommandBar launcher
     * * `keyboard`: Cmd/Ctrl+K
     * * `programmatic`: Call to `window.CommandBar.open()`. Clicks on the
     *   [commandbar-launcher](https://www.npmjs.com/package/commandbar-launcher) component register as programmatic
     *   opens.
     */
    trigger: 'launcher' | 'keyboard' | 'programmatic' | 'nudge';
    /** The placeholder showing when the user opened the bar. */
    placeholder: string;
}
export declare type OpenedEventTrigger = OpenedEvent['trigger'];
export interface NoResultsForQueryEvent {
    type: 'no_results_for_query';
    /** Event data passed for `no_results_for_query` event */
    /** The user's input text when the no results state was reached. */
    inputText: string;
}
export declare type EventData = AbandonedSearchEvent | ClosedEvent | CommandExecutionEvent | CommandSuggestionEvent | NudgeEvent | OpenedEvent | NoResultsForQueryEvent | EndUserShortcutChangedEvent;
export declare type EventHandler = (eventName: EventType, eventData: EventData) => void;
export declare type EventSubscriber = EventHandler;
export declare type EventType = 'abandoned_search' | 'command_suggestion' | 'command_execution' | 'nudge_seen' | 'nudge_clicked' | 'opened' | 'closed' | 'no_results_for_query' | 'client_error' | 'shortcut_edited';
export {};
