import { IOrganizationType } from '../middleware/OrganizationV';
import { PublicDisposable } from '../util/Disposable';
declare type ExtraData = Record<string, unknown>;
export interface UserScopeOptions {
    configuration: {
        uuid?: string;
        api: string;
        editor: string;
        proxy: string;
        session: string;
    };
    organization?: IOrganizationType;
    organizationId: string | number;
    organizationName?: string;
    session: string;
    userId?: string;
}
declare enum Severity {
    Fatal = "fatal",
    Error = "error",
    Warning = "warning",
    Log = "log",
    Info = "info",
    Debug = "debug",
    Critical = "critical"
}
interface Breadcrumb {
    type?: string;
    level?: Severity;
    event_id?: string;
    category?: string;
    message?: string;
    data?: {
        [key: string]: any;
    };
    timestamp?: number;
}
interface BreadcrumbHint {
    [key: string]: any;
}
export declare abstract class SentryReporter implements PublicDisposable {
    _disposed: boolean;
    breadcrumb: (breadcrumb: Breadcrumb, hint?: BreadcrumbHint) => void;
    dispose(): void;
    /**
     * Report an error to Sentry. The first argument must either be a string or error object, and optionally an error
     * object and extra data (in the form of an object) may be provided as well.
     *
     * If a string message is provided instead of an Error object a new Error will be generated. This will cause the
     * stacktrace to begin at this function; for that reason it is **strongly** recommended to provide an error object
     * so that the original stack trace can be preserved (as originalException).
     */
    abstract exception(message: string, err?: Error, extra?: ExtraData): void;
    abstract exception(message: string, extra?: ExtraData): void;
    abstract exception(err: Error, extra?: ExtraData): void;
    /**
     * Assigns various scope properties related to the currently active user and organization so that error events can
     * be easily associated with them.
     */
    abstract setUserScope(opts: UserScopeOptions): void;
}
export {};
