/*******************************************************************************/
import * as t from 'io-ts';
import { BatchEditorCommandResponseV, BatchOperationV, CommandV, HelpSyncCommandV, EditorCommandV } from './command';
import { ArgumentMapV, ArgumentTypeV, ConditionV, ConditionOperatorV, StepArgumentTypeV, ContextArgumentV, SetArgumentV, DynamicArgumentV, DependentArgumentV, FunctionArgumentV } from './helpers/argument';
import { GenericBatchRequest } from './generics';
import { OptionGroupRenderAsV } from './helpers/optionGroup';
import { TemplateV, TemplateOptionsV, RequestTemplateV } from './helpers/commandTemplate';
import { RequestV } from './helpers/actions';
import { CommandCategoryV } from './commandCategory';
import { OrganizationStatusV, KeyEventV, ResourceSettingsByContextKeyV, InternalSettingsV, OrganizationSettingsV } from './organization';
import { UserV } from './user';
import { ContextV } from './context';
import { GuideV } from './guide';
import { HistoryEventV } from './historyEvent';
import { HelpDocsSyncV } from './helpDocsSync';
import { HelpDocsIntegrationV } from './helpDocsIntegration';
import { EndUserV } from './helpers/endUser';
import { SkinV } from './skin';
import { ProfileV } from './profile';
import { PlaceholderV } from './placeholder';
import { EnvReleaseInfoV, ReleaseStepV, ReleaseV } from './releases';
import { EnvironmentV } from './environment';
import { NudgeContentBlockV, NudgeContentButtonBlockV, NudgeContentHelpDocBlockV, NudgeContentImageBlockV, NudgeContentMarkdownBlockV, NudgeContentVideoBlockV, NudgeStepV, NudgeV, OldNudgeV } from './nudge';
import { TabV } from './tab';
import { RuleExpressionAndV, RuleExpressionOrV, RuleExpressionV } from './helpers/rules';
import { ChecklistItemV, ChecklistV } from './checklist';
import { DashboardFlagsV } from './dashboardFlags';
/*******************************************************************************/
export declare type IInitOptions = {
    debug?: boolean;
    environment?: string;
    version?: string;
    config?: IConfigEndpointResponse;
};
/*******************************************************************************/
export declare type IContextType = t.TypeOf<typeof ContextV> & unknown;
export declare type IUserType = t.TypeOf<typeof UserV> & unknown;
export declare type ICommandType = t.TypeOf<typeof CommandV> & unknown;
export declare type IEditorCommandType = t.TypeOf<typeof EditorCommandV> & unknown;
export declare type IHelpSyncCommandType = t.TypeOf<typeof HelpSyncCommandV> & unknown;
export type { ICommandFromClientType } from './ICommandFromClientType';
export declare type ICommandCategoryType = t.TypeOf<typeof CommandCategoryV> & unknown;
export declare type IGuideType = t.TypeOf<typeof GuideV> & {
    preview?: boolean;
} & unknown;
export declare type IHistoryEventType = t.TypeOf<typeof HistoryEventV> & unknown;
export declare type IHelpDocsSyncType = t.TypeOf<typeof HelpDocsSyncV> & unknown;
export declare type IHelpDocsIntegrationType = t.TypeOf<typeof HelpDocsIntegrationV> & unknown;
export type { IOrganizationType } from './OrganizationV';
export declare type IOrganizationStatusType = t.TypeOf<typeof OrganizationStatusV> & unknown;
export declare type IInternalSettingsType = t.TypeOf<typeof InternalSettingsV> & unknown;
export declare type IDashboardFlagsType = t.TypeOf<typeof DashboardFlagsV> & unknown;
export declare type ISkinType = t.TypeOf<typeof SkinV> & unknown;
export declare type IProfileType = t.TypeOf<typeof ProfileV> & unknown;
export declare type IOrganizationSettingsType = t.TypeOf<typeof OrganizationSettingsV> & unknown;
export declare type IPlaceholderType = t.TypeOf<typeof PlaceholderV> & unknown;
export declare type ITabType = t.TypeOf<typeof TabV> & unknown;
export declare type IEnvironmentType = t.TypeOf<typeof EnvironmentV> & unknown;
export declare type IReleaseStep = t.TypeOf<typeof ReleaseStepV> & unknown;
export declare type IRelease = t.TypeOf<typeof ReleaseV> & unknown;
export declare type IEnvReleaseInfo = t.TypeOf<typeof EnvReleaseInfoV> & unknown;
/*******************************************************************************/
export declare type IBatchOperation = t.TypeOf<typeof BatchOperationV> & unknown;
export declare type IBatchEditorCommandRequst = t.TypeOf<typeof GenericBatchRequest> & unknown;
export declare type IBatchEditorCommandResponse = t.TypeOf<typeof BatchEditorCommandResponseV> & unknown;
/*******************************************************************************/
export declare type IKeyEventCategory = t.TypeOf<typeof KeyEventV> & unknown;
export declare type IArgumentMap = t.TypeOf<typeof ArgumentMapV> & unknown;
export declare type IArgumentType = t.TypeOf<typeof ArgumentTypeV> & unknown;
export declare type IStepArgumentType = t.TypeOf<typeof StepArgumentTypeV> & unknown;
export declare type ITemplate = t.TypeOf<typeof TemplateV> & unknown;
export declare type RequestTemplateType = t.TypeOf<typeof RequestTemplateV> & unknown;
export declare type RequestType = t.TypeOf<typeof RequestV> & unknown;
export declare type ITemplateOptions = t.TypeOf<typeof TemplateOptionsV> & unknown;
export declare type IEndUserType = t.TypeOf<typeof EndUserV> & unknown;
export declare type IRuleExpression = t.TypeOf<typeof RuleExpressionV> & unknown;
export declare type IRuleExpressionAnd = t.TypeOf<typeof RuleExpressionAndV> & unknown;
export declare type IRuleExpressionOr = t.TypeOf<typeof RuleExpressionOrV> & unknown;
export declare type IConditionType = t.TypeOf<typeof ConditionV> & unknown;
export declare type IConditionOperatorType = t.TypeOf<typeof ConditionOperatorV> & unknown;
export declare type IContextArgumentType = t.TypeOf<typeof ContextArgumentV> & unknown;
export declare type ISetArgumentType = t.TypeOf<typeof SetArgumentV> & unknown;
export declare type IDynamicArgumentType = t.TypeOf<typeof DynamicArgumentV> & unknown;
export declare type IDependentArgumentType = t.TypeOf<typeof DependentArgumentV> & unknown;
export declare type IFunctionArgumentType = t.TypeOf<typeof FunctionArgumentV> & unknown;
export declare type OptionGroupRenderAsType = t.TypeOf<typeof OptionGroupRenderAsV> & unknown;
export declare type IOldNudgeType = t.TypeOf<typeof OldNudgeV> & unknown;
export declare type INudgeType = t.TypeOf<typeof NudgeV> & unknown;
export declare type INudgeStepType = t.TypeOf<typeof NudgeStepV> & unknown;
export declare type INudgeStepContentBlockType = t.TypeOf<typeof NudgeContentBlockV> & unknown;
export declare type INudgeStepContentMarkdownBlockType = t.TypeOf<typeof NudgeContentMarkdownBlockV> & unknown;
export declare type INudgeStepContentImageBlockType = t.TypeOf<typeof NudgeContentImageBlockV> & unknown;
export declare type INudgeStepContentVideoBlockType = t.TypeOf<typeof NudgeContentVideoBlockV> & unknown;
export declare type INudgeStepContentHelpDocBlockType = t.TypeOf<typeof NudgeContentHelpDocBlockV> & unknown;
export declare type INudgeStepContentButtonBlockType = t.TypeOf<typeof NudgeContentButtonBlockV> & unknown;
export declare type INudgeClientType = {
    nudge: INudgeType;
    passedConditionsInLastEvaluation: boolean;
    lastTriggeredTs?: number;
};
export declare type IChecklist = t.TypeOf<typeof ChecklistV> & unknown;
export declare type IChecklistItem = t.TypeOf<typeof ChecklistItemV> & unknown;
export interface ICommandInput {
    text: string;
    command: ICommandType;
    context: IUserContext;
}
export interface IArgValues {
    [arg: string]: string | number | undefined;
}
export declare type IHistoryType = Array<{
    activeCommand: ICommandType;
    options: ICommandType[];
}>;
export interface IUserContext {
    [variable: string]: any;
}
export interface IEndUserAnalytics {
    num_command_executions: number;
    num_shortcut_command_executions: number;
    num_sessions: number;
    num_opens: number;
    num_deadends: number;
    first_seen_at: string;
    last_seen_at: string;
}
export interface ICallbackMap {
    [variable: string]: (...args: any[]) => unknown;
}
export interface IResourceType extends IUserContext {
    _cbLinkedCommmands: Array<{
        command: number;
        arg: string;
    }>;
}
export declare type IConfigEndpointResponse = {
    commands: any[];
    categories: any[];
    organization: any;
    environments_with_versions?: any[];
    placeholders?: any[];
    nudges?: IOldNudgeType[];
    nudges_v2?: INudgeType[];
    tabs?: ITabType[];
    checklists?: IChecklist[];
};
export type { IResourceSettings } from './IResourceSettings';
export declare type IResourceSettingsByContextKey = t.TypeOf<typeof ResourceSettingsByContextKeyV> & unknown;
export type { DetailPreviewObjectType, DetailPreviewType, DataRowMetadata } from './detailPreview';
/*******************************************************************************/
export declare const isCommand: (command?: ICommandType | any) => command is ICommandType;
export declare const isResource: (option: any) => option is IResourceType;
export declare const isContextArgument: (argument: IArgumentType) => argument is IContextArgumentType;
export declare const isTimeArgument: (argument: IArgumentType) => argument is IDynamicArgumentType;
export declare const isFunctionArgument: (argument: IArgumentType) => argument is IFunctionArgumentType;
