#!/usr/bin/env ts-node

import * as ts from 'typescript';
import { snippet } from '../src/snippet';
import { minify } from 'terser';

const result = ts.transpileModule(snippet.toString(), {
  compilerOptions: {
    alwaysStrict: false,
    declaration: false,
    lib: ['DOM', 'ES2015'],
    module: ts.ModuleKind.None,
    noEmitOnError: true,
    removeComments: true,
    sourceMap: false,
    strict: true,
    target: ts.ScriptTarget.ES5,
  },
});

if (result.diagnostics && result.diagnostics.length > 0) {
  result.diagnostics?.forEach((d) => console.error(d.messageText));
  process.exit(1);
}

const lines = result.outputText.split('\n');
const transpiled = ["var org = '<org_id>';"].concat(lines.slice(1, lines.length - 2)).join('\n');

minify(transpiled, { mangle: { toplevel: true } })
  .then((result) => {
    console.log(result.code);
  })
  .catch((err) => {
    console.error(err);
    process.exit(1);
  });
