/* eslint-disable no-template-curly-in-string */
/* eslint-disable prefer-rest-params */

import { _eventSubscriptions } from '../../internal/src/client/symbols';

/* eslint-disable @typescript-eslint/no-inferrable-types */
export const snippet = (org: string) => {
  const polyfills = ['Object.assign', 'Symbol', 'Symbol.for'].join('%2C');
  const w = window as unknown as Record<string, unknown>;

  function loadScript(src: string, async = false) {
    if (document.readyState !== 'complete') {
      window.addEventListener('load', loadScript.bind(null, src, async), { capture: false, once: true });
    }
    const el = document.createElement('script');
    el.type = 'text/javascript';
    el.async = async;
    el.src = src;
    document.head.appendChild(el);
  }

  function bootstrap() {
    if (w.CommandBar !== undefined) return;
    delete w.__CommandBarBootstrap__;

    const _configuration = Symbol.for('CommandBar::configuration');
    const _orgConfig = Symbol.for('CommandBar::orgConfig');
    const _disposed = Symbol.for('CommandBar::disposed');
    const _isProxy = Symbol.for('CommandBar::isProxy');
    const _queue = Symbol.for('CommandBar::queue');
    const _unwrap = Symbol.for('CommandBar::unwrap');
    const params = [];
    const lc = localStorage.getItem('commandbar.lc');
    const origin = lc && lc.includes('local') ? 'http://localhost:8000' : 'https://api.commandbar.com';

    const proxy = Object.assign(
      {
        [_configuration]: { uuid: org },
        [_orgConfig]: {},
        [_disposed]: false,
        [_isProxy]: true,
        [_queue]: new Array<unknown>(),
        [_unwrap]: () => proxy,
        [_eventSubscriptions]: undefined,
      },
      w.CommandBar,
    );

    const ASYNC_METHODS_SNIPPET = ['addCommand', 'boot', 'addEventSubscriber', 'addRecordAction', 'setFormFactor'];

    const sdk = proxy;

    Object.assign(proxy, {
      shareCallbacks: () => ({}),
      shareContext: () => ({}),
    });

    w.CommandBar = new Proxy(proxy, {
      get: function (_, prop) {
        if (prop in sdk) return proxy[prop];
        if (ASYNC_METHODS_SNIPPET.includes(prop as string)) {
          return function () {
            // eslint-disable-next-line prefer-rest-params
            const a = Array.prototype.slice.call(arguments);
            return new Promise((resolve, reject) => {
              a.unshift(prop, resolve, reject);
              (proxy[_queue] as Array<unknown>).push(a);
            });
          };
        }
        return function () {
          // eslint-disable-next-line prefer-rest-params
          const a = Array.prototype.slice.call(arguments);
          a.unshift(prop);
          (proxy[_queue] as Array<unknown>).push(a);
        };
      },
    });

    if (lc !== null) params.push(`lc=${lc}`);
    params.push('version=2');

    loadScript(`${origin}/latest/${org}?${params.join('&')}`, true);
  }

  if (typeof Object.assign === 'undefined' || typeof Symbol === 'undefined' || typeof Symbol.for === 'undefined') {
    w.__CommandBarBootstrap__ = bootstrap;
    loadScript(
      'https://polyfill.io/v3/polyfill.min.js?version=3.101.0&callback=__CommandBarBootstrap__&features=' + polyfills,
    );
  } else {
    bootstrap();
  }
};
